var __defProp = Object.defineProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};

// src/Adaptor.js
var Adaptor_exports = {};
__export(Adaptor_exports, {
  alterState: () => alterState,
  dataPath: () => dataPath,
  dataValue: () => dataValue,
  each: () => each,
  execute: () => execute,
  field: () => field,
  fields: () => fields,
  findDocuments: () => findDocuments,
  fn: () => fn,
  fnIf: () => fnIf,
  insertDocuments: () => insertDocuments,
  lastReferenceValue: () => lastReferenceValue,
  merge: () => merge,
  sourceValue: () => sourceValue,
  updateDocument: () => updateDocument
});
import {
  execute as commonExecute,
  expandReferences,
  composeNextState
} from "@openfn/language-common";
import pkg from "mongodb";
import {
  field,
  fields,
  sourceValue,
  fn,
  fnIf,
  alterState,
  each,
  merge,
  dataPath,
  dataValue,
  lastReferenceValue
} from "@openfn/language-common";
var { MongoClient } = pkg;
function execute(...operations) {
  const initialState = {
    references: [],
    data: null
  };
  return (state) => {
    return commonExecute(
      connect,
      ...operations,
      disconnect
    )({ ...initialState, ...state });
  };
}
function connect(state) {
  const { clusterHostname, username, password } = state.configuration;
  const uri = `mongodb+srv://${encodeURIComponent(
    username
  )}:${encodeURIComponent(
    password
  )}@${clusterHostname}/test?retryWrites=true&w=majority`;
  const client = new MongoClient(uri, { useNewUrlParser: true });
  return new Promise((resolve, reject) => {
    client.connect((err) => {
      if (err) {
        reject(err);
      } else {
        console.log("Connected successfully to server");
        resolve({ ...state, client });
      }
    });
  });
}
function disconnect(state) {
  state.client.close();
  delete state.client;
  return state;
}
function insertDocuments(params) {
  return (state) => {
    const { client } = state;
    try {
      const { database, collection, documents, callback } = expandReferences(params)(state);
      const db = client.db(database);
      const mCollection = db.collection(collection);
      return new Promise((resolve, reject) => {
        mCollection.insertMany(documents, (err, result) => {
          if (err) {
            reject(err);
            state.client.close();
          } else {
            console.log(
              `Inserted ${documents.length} documents into the collection`
            );
            console.log(JSON.stringify(result, null, 2));
            const nextState = composeNextState(state, result);
            if (callback)
              resolve(callback(nextState));
            resolve(nextState);
          }
        });
      });
    } catch (error) {
      state.client.close();
      throw error;
    }
  };
}
function findDocuments(params) {
  return (state) => {
    const { client } = state;
    try {
      const { database, collection, query, callback } = expandReferences(params)(state);
      const db = client.db(database);
      const mCollection = db.collection(collection);
      return new Promise((resolve, reject) => {
        mCollection.find(query).toArray((err, docs) => {
          if (err) {
            reject(err);
            state.client.close();
          } else {
            console.log(`Found ${docs.length} documents in the collection`);
            console.log(JSON.stringify(docs, null, 2));
            const nextState = composeNextState(state, docs);
            if (callback)
              resolve(callback(nextState));
            resolve(nextState);
          }
        });
      });
    } catch (error) {
      state.client.close();
      throw error;
    }
  };
}
function updateDocument(params) {
  return (state) => {
    const { client } = state;
    try {
      const { database, collection, filter, changes, options, callback } = expandReferences(params)(state);
      const db = client.db(database);
      const mCollection = db.collection(collection);
      return new Promise((resolve, reject) => {
        mCollection.updateMany(
          filter,
          { $set: changes },
          options,
          (err, result) => {
            if (err) {
              reject(err);
              state.client.close();
            } else {
              console.log(
                `Updated a document matching ${JSON.stringify(
                  filter
                )} in the collection.`
              );
              console.log(JSON.stringify(result, null, 2));
              const nextState = composeNextState(state, result);
              if (callback)
                resolve(callback(nextState));
              resolve(nextState);
            }
          }
        );
      });
    } catch (error) {
      state.client.close();
      throw error;
    }
  };
}

// src/index.js
var src_default = Adaptor_exports;
export {
  alterState,
  dataPath,
  dataValue,
  src_default as default,
  each,
  execute,
  field,
  fields,
  findDocuments,
  fn,
  fnIf,
  insertDocuments,
  lastReferenceValue,
  merge,
  sourceValue,
  updateDocument
};
