/**
 * Execute a sequence of operations.
 * Wraps `@openfn/language-common/execute`, and prepends initial state for http.
 * @example
 * execute(
 *   insertDocuments(params),
 *   findDocuments(params)
 * )(state)
 * @function
 * @param {Operations} operations - Operations to be performed.
 * @returns {Operation}
 */
export function execute(...operations: Operations): Operation;
/**
 * Inserts documents into a mongoDb collection
 * @example
 *  insertDocuments({
 *    database: 'str',
 *    collection: 'kids',
 *    documents: [1,2,3]
 *   });
 * @function
 * @public
 * @param {object} params - Configuration for mongo
 * @returns {State}
 */
export function insertDocuments(params: object): State;
/**
 * Find documents in a mongoDb collection
 * @example
 *  findDocuments({
 *    database: 'str',
 *    collection: 'cases',
 *    query: {a:3}
 *   });
 * @function
 * @public
 * @param {object} params - Configuration for mongo
 * @returns {State}
 */
export function findDocuments(params: object): State;
/**
 * Updates document (optionally upserting) into a mongoDb collection
 * @example
 *  updateDocuments({
 *    database: 'str',
 *    collection: 'animals',
 *    filter: { type: 'fuzzy' },
 *    changes: { kind: 'soft' },
 *    options: { upsert: true }
 *   });
 * @function
 * @public
 * @param {object} params - Configuration for mongo
 * @returns {State}
 */
export function updateDocument(params: object): State;
export { field, fields, sourceValue, fn, fnIf, alterState, each, merge, dataPath, dataValue, lastReferenceValue } from "@openfn/language-common";
